restish.error — Restish v0.5 documentation

### Navigation

- index
- modules |
- Restish v0.5 documentation »

Overview

# restish.error

exception `restish.error.` `HTTPClientError`

  Bases: `restish.error.RestishException`

  Base class for all HTTP client (4xx) errors.

  Each 4xx response is mirrored by an exception type that subclasses from HTTPClientException. The subclass should override response_factory setting it to a callable that will accept all the positional and keyword args and return an http.Response instance.

  Typically, response_factory factory can be set to one of the convenience functions in the http module.

  `make_response`()
    Create an HTTP response for this exception type.

exception `restish.error.` `RestishException`

  Bases: `exceptions.Exception`

  Base class for all restish exceptions.

### Navigation

- index
- modules |
- Restish v0.5 documentation »